pilas.fisica.Figura

Package pilas :: Module fisica :: Class Figura |
[hide private]
[frames] | no frames]

# Class Figura

source code

    object --+
             |
            Figura

Known Subclasses:
  - Circulo
  - , Poligono
  - , Rectangulo

Representa un figura que simula un cuerpo fisico.

Esta figura es abstracta, no está pensada para crear objetos a partir de ella. Se usa como base para el resto de las figuras cómo el Circulo o el Rectangulo simplemente.

Instance Methods | [hide private]
__init__(self) x.__init__(...) initializes x; see help(type(x)) for signature | source code
obtener_x(self) Retorna la posición horizontal del cuerpo. | source code
definir_x(self, x) Define la posición horizontal del cuerpo. | source code
obtener_y(self) Retorna la posición vertical del cuerpo. | source code
definir_y(self, y) Define la posición vertical del cuerpo. | source code
definir_posicion(self, x, y) Define la posición para el cuerpo. | source code
obtener_rotacion(self) | source code
definir_rotacion(self, angulo) | source code
impulsar(self, dx, dy) | source code
obtener_velocidad_lineal(self) | source code
detener(self) Hace que la figura regrese al reposo. | source code
definir_velocidad_lineal(self, dx=None, dy=None) | source code
empujar(self, dx=None, dy=None) | source code
eliminar(self) Quita una figura de la simulación. | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
| x define la posición horizontal.
| y define la posición vertical.
| rotacion define la rotacion.
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### definir_x(self, x) | source code
Define la posición horizontal del cuerpo. :param x: El valor horizontal a definir.

### definir_y(self, y) | source code
Define la posición vertical del cuerpo. :param y: El valor vertical a definir.

### definir_posicion(self, x, y) | source code
Define la posición para el cuerpo. :param x: Posición horizontal que se asignará al cuerpo. :param y: Posición vertical que se asignará al cuerpo.

Property Details | [hide private]

### x define la posición horizontal. Get Method: obtener_x(self) - Retorna la posición horizontal del cuerpo. Set Method: definir_x(self, x) - Define la posición horizontal del cuerpo.

### y define la posición vertical. Get Method: obtener_y(self) - Retorna la posición vertical del cuerpo. Set Method: definir_y(self, y) - Define la posición vertical del cuerpo.

### rotacion define la rotacion. Get Method: obtener_rotacion(self) Set Method: definir_rotacion(self, angulo)